Lights

Struct Lights 

pub struct Lights { /* private fields */ }
A selection of button lights on the tablet. There are 10 buttons with 4 lights each for a total of 40 lights.

Ordering

The order is in `Button’ order from Button::B0 to Button::B9 where each button has 4 lights together in the following order:

  • “Top”
  • “Left”
  • “Right”
  • “Bottom”

Implementations

Source

impl Lights

pub const COUNT: usize

The number of lights on Boppo. Each button has four lights.

NOTE: that this is not the number of lights in this selection which is obtained by calling self.len()

pub fn from_slice(arr: &[bool]) -> Lights

Returns a selection containing all indices marked true in arr.

Panics

This function will panic if arr.len() > Lights::COUNT

pub const fn from_index(light_index: usize) -> Lights

Returns a Lights with only the light at light_index selected.

pub fn from_indices<I>(indexes: I) -> Lights
where I: IntoIterator<Item = usize>,

Returns a new Lights constructed from light indices contained in indexes.

Panics

This function will panic if indexes contains an index >= Lights::COUNT.

pub const fn from_bitset(bits: u64) -> Lights

Returns a new Lights with bits.

Each bit in bits represents whether an individual light has been selected. The least significant bit selects Button::B1.light_at(LightDir::Top).

Ordering

See Lights ordering.

Panics

This function will panic if bits >> Lights::COUNT != 0.

pub const fn all_from_button(button: Button) -> Lights

All 4 lights of button

pub const fn all() -> Lights

Returns a Lights with every light selected

pub const fn none() -> Lights

Returns a Lights with no light selected

pub fn len(&self) -> u32

Returns the number of lights in this selection.

pub fn is_empty(&self) -> bool

Returns true if no lights are selected.

pub fn is_superset(&self, other: Self) -> bool

Returns true if other selects only buttons that self selects.

See also Lights::is_subset

pub fn is_subset(&self, other: Self) -> bool

Returns true if other selects only buttons that self selects.

See also Lights::is_superset

pub fn indices(&self) -> impl DoubleEndedIterator<Item = usize> + use<>

Returns a double-ended iterator over the indices of every Button in this selection.

pub const fn invert(&self) -> Lights

Returns the inversion of the current selection.

pub fn choose_n_randomly(&self, n: usize) -> Lights

Randomly choose n of the lights that are active in self.

pub fn rotate_180(&self) -> Lights

Return the Lights as if the device was rotate 180 degrees. Light 0 becomes 39, 1 becomes 38…

pub const fn as_bitset(&self) -> u64

A compact representation. The least significant bit represents if button 1 is pressed…

pub fn set_color(self, color: RGB)

Sets all lights in this selection to color

pub fn set_colors(self, colors: &[RGB])

Sets each light in this selection to the corresponding color in colors, up to exhaustion of either the selection or colors.

pub const fn only(self, dir: LightDir) -> Lights

Returns a new Lights with only the lights in the dir direction from this selection.